spacepy.irbempy.find_magequator — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.find_magequator

`spacepy.irbempy.` `find_magequator`(ticks, loci, extMag='T01STORM', options=[1, 0, 0, 0, 0], omnivals=None)

  call find_magequator from irbem library and return a dictionary with values for Bmin and the GEO (cartesian) coordinates of the magnetic equator

  Parameters: | - ticks (Ticktock class) : containing time information loci (Coords class) : containing spatial information extMag (string) : optional; will choose the external magnetic field model possible values [‘0’, ‘MEAD’, ‘T87SHORT’, ‘T87LONG’, ‘T89’, ‘OPQUIET’, ‘OPDYN’, ‘T96’, ‘OSTA’, ‘T01QUIET’, ‘T01STORM’, ‘T05’, ‘ALEX’] options (optional list or array of integers length=5) : explained in Lstar omni values as dictionary (optional) : if not provided, will use lookup table (see Lstar documentation for further explanation)
  Returns: | - results (dictionary) : containing keys: Bmin, Coords instance with GEO coordinates of the magnetic equator

  See also

  `get_Lstar`, `get_Bfield`, `find_Bmirr`

  Examples

      >>> t = Ticktock(['2002-02-02T12:00:00', '2002-02-02T12:10:00'], 'ISO')
      >>> y = Coords([[3,0,0],[2,0,0]], 'GEO', 'car')
      >>> op.find_magequator(t,y)
      {'Bmin': array([  945.63652413,  3373.64496167]),
          'loci': Coords( [[ 2.99938371  0.00534151 -0.03213603]
          [ 2.00298822 -0.0073077   0.04584859]] ), dtype=GEO,car, units=['Re', 'Re', 'Re']}

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »